[llvm-commits] CVS: llvm/include/llvm/Target/TargetMachine.h

Chris Lattner lattner at cs.uiuc.edu
Mon Nov 7 18:10:28 PST 2005



Changes in directory llvm/include/llvm/Target:

TargetMachine.h updated: 1.58 -> 1.59
---
Log message:

Add a new option to indicate we want the code generator to emit code quickly,
not spending tons of time microoptimizing it.  This is useful for an -O0
style of build.


---
Diffs of the changes:  (+4 -3)

 TargetMachine.h |    7 ++++---
 1 files changed, 4 insertions(+), 3 deletions(-)


Index: llvm/include/llvm/Target/TargetMachine.h
diff -u llvm/include/llvm/Target/TargetMachine.h:1.58 llvm/include/llvm/Target/TargetMachine.h:1.59
--- llvm/include/llvm/Target/TargetMachine.h:1.58	Tue Nov  1 14:07:00 2005
+++ llvm/include/llvm/Target/TargetMachine.h	Mon Nov  7 20:10:16 2005
@@ -143,11 +143,12 @@
 
   /// addPassesToEmitFile - Add passes to the specified pass manager to get
   /// the specified file emitted.  Typically this will involve several steps of
   /// code generation.  This method should return true if emission of this file
   /// type is not supported.
   ///
   virtual bool addPassesToEmitFile(PassManager &PM, std::ostream &Out,
-                                   CodeGenFileType FileType) {
+                                   CodeGenFileType FileType, bool Fast) {
     return true;
   }
 
@@ -143,11 +143,12 @@
   /// addPassesToEmitFile - Add passes to the specified pass manager to get
   /// the specified file emitted.  Typically this will involve several steps of
-  /// code generation.  This method should return true if emission of this file
-  /// type is not supported.
+  /// code generation.  If Fast is set to true, the code generator should emit
+  /// code as fast as possible, without regard for compile time.  This method
+  /// should return true if emission of this file type is not supported.
   ///
   virtual bool addPassesToEmitFile(PassManager &PM, std::ostream &Out,






More information about the llvm-commits mailing list